package com.fs.course.service;

import com.fs.course.domain.FsUserCourseCommentLike;

import java.util.List;

/**
 * 课堂评论点赞Service接口
 *
 * @author fs
 * @date 2024-05-15
 */
public interface IFsUserCourseCommentLikeService
{
    /**
     * 查询课堂评论点赞
     *
     * @param id 课堂评论点赞主键
     * @return 课堂评论点赞
     */
    public FsUserCourseCommentLike selectFsUserCourseCommentLikeById(Long id);

    /**
     * 查询课堂评论点赞列表
     *
     * @param fsUserCourseCommentLike 课堂评论点赞
     * @return 课堂评论点赞集合
     */
    public List<FsUserCourseCommentLike> selectFsUserCourseCommentLikeList(FsUserCourseCommentLike fsUserCourseCommentLike);

    /**
     * 新增课堂评论点赞
     *
     * @param fsUserCourseCommentLike 课堂评论点赞
     * @return 结果
     */
    public int insertFsUserCourseCommentLike(FsUserCourseCommentLike fsUserCourseCommentLike);

    /**
     * 修改课堂评论点赞
     *
     * @param fsUserCourseCommentLike 课堂评论点赞
     * @return 结果
     */
    public int updateFsUserCourseCommentLike(FsUserCourseCommentLike fsUserCourseCommentLike);

    /**
     * 批量删除课堂评论点赞
     *
     * @param ids 需要删除的课堂评论点赞主键集合
     * @return 结果
     */
    public int deleteFsUserCourseCommentLikeByIds(Long[] ids);

    /**
     * 删除课堂评论点赞信息
     *
     * @param id 课堂评论点赞主键
     * @return 结果
     */
    public int deleteFsUserCourseCommentLikeById(Long id);


    FsUserCourseCommentLike selectFsUserCourseCommentLikeByUserIdAndCommentId(Long userId, Long commentId);
}
